@@ -880,7 +880,7 @@ class World:
         self.window.unknown_key_pressed = self.__build_key_function
 
     def build_key_pressed(self):
-        print("b pressed")
+        print("b pressed.")
 
     def __build_key_function(self, symbol):
         #print(symbol, "pressed")
@@ -962,7 +962,7 @@ def main():
     
     # Eine Funktion, die beim Drücken der B-Taste aufgerufen werden soll
     def b_key_pressed(world:World):
-        print("B pressed. Player at", world.play_position)
+        print("B pressed. Player at", world.play_position())
         
     # Erstellen einer neuen Welt
     world = World()
@@ -982,6 +982,7 @@ def main():
         # air, default:brick, default:stone, default:sand, default:grass
         print("Block types", World.MATERIALS)
         x,y,z = world.player_position()
+        # Einen Block platzieren
         world.setBlock(x,y,z, "default:brick")
 
         # Mehrere Blöcke auf einmal abseits des Spielers platzieren
